@@ -44,7 +44,7 @@ class Stream(
         String("stream-send-queue", default="mq-master"),
         Int("stream-send-queue-max-length", default=1000),
         Bool("stream-send-queue-trim-immediately", default=False),
-        String("stream-sio-static-folder", default="/dev/shm/web"),
+        String("stream-sio-static-folder", default="/web"),
         String("stream-sio-static-url-prefix", default="/"),
     ]
     STREAM_PARAMS_FILE = "params.json"
